@@ -53,11 +53,12 @@ def connect(client: IColaboFlowClientData):
 	"""
 	connects to the ColaboFlow service through the RabbitMQ broker
 	"""
-	print(f"{client.appNameTextWithContext('connect')} Connecting to the server...")
+	port = 5672
+	print(f"{client.appNameTextWithContext('connect')} Connecting to the server... (host: {client.amqpUrl}, port: {port})")
 	parameters = (
 		pika.ConnectionParameters(
 			host=client.amqpUrl,
-			port=5672,
+			port=port,
 			connection_attempts=5,
 			retry_delay=1
 		)
