@@ -287,8 +287,8 @@ def listenOnHostQueue(host: IColaboFlowHostData):
 	# Note: prefetch is set to 1 here as an example only and to keep the number of threads created
 	# to a reasonable amount. In production you will want to test with different prefetch values
 	# to find which one provides the best performance and usability for your solution
-	host.chHostHeartbeat.basic_qos(prefetch_count=1)
-	# host.chHostHeartbeat.basic_qos(prefetch_count=2)
+	# host.chHostHeartbeat.basic_qos(prefetch_count=1)
+	host.chHostHeartbeat.basic_qos(prefetch_count=host.concurrency_TasksNo)
 
 	# https://pika.readthedocs.io/en/stable/modules/channel.html#pika.channel.Channel.basic_consume
 	# https://stackoverflow.com/questions/50404273/python-tutorial-code-from-rabbitmq-failing-to-run
